/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

import ClayList from '@clayui/list';
import ClayPanel from '@clayui/panel';
import React, {useMemo, useState} from 'react';

import PanelHeaderWithOptions from '../../../shared/components/panel-header-with-options/PanelHeaderWithOptions.es';
import PromisesResolver from '../../../shared/components/promises-resolver/PromisesResolver.es';
import Tabs from '../../../shared/components/tabs/Tabs.es';
import {useFilter} from '../../../shared/hooks/useFilter.es';
import {usePost} from '../../../shared/hooks/usePost.es';
import ProcessStepFilter from '../../filter/ProcessStepFilter.es';
import Body from './WorkloadByAssigneeCardBody.es';

function Header({processId}) {
	return (
		<>
			<PanelHeaderWithOptions
				className="tabs-panel-header"
				description={Liferay.Language.get(
					'workload-by-assignee-description'
				)}
				title={Liferay.Language.get('workload-by-assignee')}
				tooltipPosition="bottom"
			/>

			<div className="management-bar management-bar-light ml-3 navbar navbar-expand-md pl-1">
				<ClayList className="navbar-nav">
					<ProcessStepFilter
						options={{
							hideControl: true,
							multiple: false,
							withAllSteps: true,
							withSelectionTitle: true,
						}}
						processId={processId}
					/>
				</ClayList>
			</div>
		</>
	);
}

function WorkloadByAssigneeCard({routeParams}) {
	const {processId} = routeParams;
	const [currentTab, setCurrentTab] = useState('overdue');
	const filterKeys = ['processStep'];

	const {
		filterValues: {taskNames: [taskName] = ['allSteps']},
	} = useFilter({filterKeys});

	const sortItems = {
		onTime: 'onTimeTaskCount:desc',
		overdue: 'overdueTaskCount:desc',
		total: 'taskCount:desc',
	};

	const sort = sortItems[currentTab];

	const taskNames = taskName !== 'allSteps' ? [taskName] : undefined;

	const {data, postData} = usePost({
		body: {taskNames},
		params: {
			page: 1,
			pageSize: 10,
			sort,
		},
		url: `/processes/${processId}/assignees/metrics`,
	});

	const promises = useMemo(
		() => [postData()],

		// eslint-disable-next-line react-hooks/exhaustive-deps
		[routeParams]
	);

	const tabs = [
		{name: Liferay.Language.get('overdue'), tabKey: 'overdue'},
		{name: Liferay.Language.get('on-time'), tabKey: 'onTime'},
		{name: Liferay.Language.get('total'), tabKey: 'total'},
	];

	return (
		<PromisesResolver promises={promises}>
			<ClayPanel className="mt-4 workload-by-assignee-card">
				<WorkloadByAssigneeCard.Header processId={processId} />

				<div className="border-bottom container-nav">
					<Tabs
						currentTab={currentTab}
						setCurrentTab={setCurrentTab}
						tabs={tabs}
					/>
				</div>

				<WorkloadByAssigneeCard.Body
					currentTab={currentTab}
					{...data}
					processStepKey={taskNames && taskName}
					{...routeParams}
				/>
			</ClayPanel>
		</PromisesResolver>
	);
}

WorkloadByAssigneeCard.Body = Body;
WorkloadByAssigneeCard.Header = Header;

export default WorkloadByAssigneeCard;
